A scriptable file/process/network scanner
sscan is a scriptable file, process, and network scanner. Its high level of configurability is powered by userscripts which run in an embeded Lua virtual machine.
Currently, scanning is provided by the YARA-X scan engine. YARA-X is a Rust implementation of the original YARA scan engine. Additional scan engines may be implemented or integrated in the future.
The embedded Lua virtual machine is made possible by the mlua crate.
Getting Started
First of all, install sscan by running the following:
cargo install --locked sscanTo try out sscan interactively, run:
sscan interactiveOr, if you’ve already created a Lua userscript, run:
sscan run myscript.luaThe commandline arguments can be abbreviated, as long as they are
unambiguous. For example, sscan int or sscan i will start an
interactive session, just like the full command.
Getting Help
To access the built-in help system, call (from Lua):
help() -- View general help overview
help:topics() -- List all available help topics
help 'topic_name' -- View detailed help on a topic.Help topics are also available in the topics module.
Modules
- actors
- The distributed actors that make up sscan.
- userscript_
api - The Lua Userscript API